<?php
/**
* 2007-2019 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2019 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class Rapidexpress extends CarrierModule
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'rapidexpress';
        $this->tab = 'shipping_logistics';
        $this->version = '2.2.1';
        $this->author = 'Plat-on';
        $this->need_instance = 0;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('RapidExpress');
        $this->description = $this->l('Genera los envíos a través del proveedor RapidExpress');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        if (extension_loaded('curl') == false)
        {
            $this->_errors[] = $this->l('You have to enable the cURL extension on your server to install this module');
            return false;
        }

        include_once dirname(__FILE__) . '/sql/install.php';

        Configuration::updateValue('RAPIDEXPRESS_LIVE_MODE', false);
        Configuration::updateValue('RAPIDEXPRESS_ID_CARRIER', null);

        $vendedor = Configuration::getMultiple(array(
			'PS_SHOP_NAME', 'PS_SHOP_EMAIL',
			'PS_SHOP_ADDR1', 'PS_SHOP_ADDR2',
			'PS_SHOP_CODE', 'PS_SHOP_CITY',
			'PS_SHOP_COUNTRY_ID', 'PS_SHOP_STATE_ID',
			'PS_SHOP_PHONE', 'PS_SHOP_FAX')
		);

		$country = new Country((int)$vendedor['PS_SHOP_COUNTRY_ID']);

		Configuration::updateValue('RAPIDEXPRESS_ORI_NOMBRE', $vendedor['PS_SHOP_NAME']);
		Configuration::updateValue('RAPIDEXPRESS_ORI_DIRECCION', $vendedor['PS_SHOP_ADDR1']);
		Configuration::updateValue('RAPIDEXPRESS_ORI_CP', $vendedor['PS_SHOP_CODE']);
		Configuration::updateValue('RAPIDEXPRESS_ORI_CIUDAD', $vendedor['PS_SHOP_CITY']);
		Configuration::updateValue('RAPIDEXPRESS_ORI_PAIS', $country->iso_code);
		Configuration::updateValue('RAPIDEXPRESS_ORI_TELEFONO', $vendedor['PS_SHOP_PHONE']);
		Configuration::updateValue('RAPIDEXPRESS_ORI_EMAIL', $vendedor['PS_SHOP_EMAIL']);

        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('updateCarrier') &&
            $this->registerHook('adminOrder');
    }

    public function uninstall()
    {
        Configuration::deleteByName('RAPIDEXPRESS_LIVE_MODE');
        include_once dirname(__FILE__) . '/sql/uninstall.php';
        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitRapidexpressModule')) == true) {
            $this->postProcess();
        }

        $this->context->smarty->assign('module_dir', $this->_path);

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitRapidexpressModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        $carriers = Carrier::getCarriers($this->context->language->id, true);
        $countries = Country::getCountries($this->context->language->id, true);
        return array(
            'form' => array(
                'legend' => array(
                	'title' => $this->l('Settings'),
                	'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'select',
                        'label' => $this->l('Carrier'),
                        'name' => 'RAPIDEXPRESS_ID_CARRIER',
                        'required' => true,
                        'options' => array(
                            'query' => $carriers,
                            'id' => 'id_carrier',
    						'name' => 'name',
                        ),
                    ),
                    
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_TOKEN',
                        'required' => true,
                        'label' => $this->l('Token'),
                    ),

                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_NOMBRE',
                        'required' => true,
                        'label' => $this->l('Name'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_DIRECCION',
                        'required' => true,
                        'label' => $this->l('Address'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_CP',
                        'required' => true,
                        'label' => $this->l('Postal Code'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Country'),
                        'name' => 'RAPIDEXPRESS_ORI_PAIS',
                        'required' => true,
                        'options' => array(
                            'query' => $countries,
                            'id' => 'iso_code',
    						'name' => 'name',
                        ),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_CIUDAD',
                        'required' => true,
                        'label' => $this->l('City'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_TELEFONO',
                        'required' => true,
                        'label' => $this->l('Phone'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'name' => 'RAPIDEXPRESS_ORI_EMAIL',
                        'required' => true,
                        'label' => $this->l('Email'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'RAPIDEXPRESS_LIVE_MODE' => Configuration::get('RAPIDEXPRESS_LIVE_MODE', true),
            'RAPIDEXPRESS_TOKEN' => Configuration::get('RAPIDEXPRESS_TOKEN', ''),
            'RAPIDEXPRESS_ID_CARRIER' => Configuration::get('RAPIDEXPRESS_ID_CARRIER', null),
            'RAPIDEXPRESS_ORI_NOMBRE' => Configuration::get('RAPIDEXPRESS_ORI_NOMBRE', ''),
            'RAPIDEXPRESS_ORI_DIRECCION' => Configuration::get('RAPIDEXPRESS_ORI_DIRECCION', ''),
            'RAPIDEXPRESS_ORI_CP' => Configuration::get('RAPIDEXPRESS_ORI_CP', ''),
            'RAPIDEXPRESS_ORI_CIUDAD' => Configuration::get('RAPIDEXPRESS_ORI_CIUDAD', ''),
            'RAPIDEXPRESS_ORI_PAIS' => Configuration::get('RAPIDEXPRESS_ORI_PAIS', ''),
            'RAPIDEXPRESS_ORI_TELEFONO' => Configuration::get('RAPIDEXPRESS_ORI_TELEFONO', ''),
            'RAPIDEXPRESS_ORI_EMAIL' => Configuration::get('RAPIDEXPRESS_ORI_EMAIL', ''),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    public function getOrderShippingCost($params, $shipping_cost)
    {
        if (Context::getContext()->customer->logged == true)
        {
            $id_address_delivery = Context::getContext()->cart->id_address_delivery;
            $address = new Address($id_address_delivery);

            /**
             * Send the details through the API
             * Return the price sent by the API
             */
            return 10;
        }

        return $shipping_cost;
    }

    public function getOrderShippingCostExternal($params)
    {
        return true;
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookBackOfficeHeader()
    {
        if (Tools::getValue('module_name') == $this->name) {
            $this->context->controller->addJS($this->_path.'views/js/back.js');
            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');
    }

    public function hookUpdateCarrier($params)
    {
        /**
         * Not needed since 1.5
         * You can identify the carrier by the id_reference
        */
    }

    public function hookAdminOrder($params)
	{
		$output = '';
		$order = new Order((int) $params['id_order']);
		$carrier = new Carrier((int) $order->id_carrier);

		if($order->id_carrier == Configuration::get('RAPIDEXPRESS_ID_CARRIER')) {

			$sql = 'SELECT * '
				. 'FROM ' . _DB_PREFIX_ . 'rapid_envios '
				. 'WHERE id_envio = ' . (int) $order->id . ' AND codigo_envio IS NOT NULL';
			$showLabelButton = (bool) Db::getInstance()->getValue($sql);
			$datosEnvio = Db::getInstance()->getRow($sql);

			if($showLabelButton){
				$albpdf = dirname(__FILE__)."/albaranes/".md5($datosEnvio['codigo_envio']).".pdf";
				if(!file_exists($albpdf)){
					$this->descargarAlbaran((int)$order->id);
				}
				if(file_exists($albpdf)){
					$linkLabel = _PS_BASE_URL_SSL_ . __PS_BASE_URI__ .'modules/'.$this->name.'/albaranes/'.md5($datosEnvio['codigo_envio']).'.pdf';
				}
			}

			if (Tools::isSubmit('generateSendrapid_envios') && !$showLabelButton) {
				$return = $this->generarEnvio((int)$order->id);
				if($return != ''){
					$errorMessage = $return;
				}else {					
					$errorMessage = '';
					$actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http")."://{$_SERVER['HTTP_HOST']}{$_SERVER['REQUEST_URI']}";				
					Tools::redirectAdmin($actual_link);	
				}											
			}			

			if(!$showLabelButton){
				$servicios = $this->getServiciosContratados();
				$listServicios = '<option></option>';
				foreach ($servicios as $servicio) {
					$listServicios .= '<option value="'.$servicio['id'].'">'.$servicio['nombre'].'</option>';
				}

				$delivery = new Address((int) $order->id_address_delivery);
				$country = new Country((int) $delivery->id_country);
				$customer = new Customer((int)$order->id_customer);
				$messageList = Message::getMessagesByOrderId((int)$order->id);

				$RAPIDEXPRESS_REFERENCE = $order->reference;
				$RAPIDEXPRESS_ORDER_COMMENTS = (isset($messageList['0']) && $messageList['0']['id_customer'] > 0) ? $messageList['0']['message'] : '';
				$RAPIDEXPRESS_DEST_CONTACT_INFO = $delivery->firstname. ' '. $delivery->lastname;
				$RAPIDEXPRESS_DEST_PHONE = ($delivery->phone != '') ? $delivery->phone : $delivery->phone_mobile;
				$RAPIDEXPRESS_DEST_CP = $delivery->postcode;
				$RAPIDEXPRESS_DEST_CITY = $delivery->city;
				$RAPIDEXPRESS_DEST_ADDRESS = $delivery->address1;
				$RAPIDEXPRESS_DEST_COUNTRY = $country->iso_code;
				$RAPIDEXPRESS_DEST_EMAIL = $customer->email;
				$RAPIDEXPRESS_DEST_COD = ($order->total_shipping_tax_excl);
				$RAPIDEXPRESS_SERV = $listServicios;
				$RAPIDEXPRESS_ALBARAN = '';

			}else{
				$delivery = new Address((int) $order->id_address_delivery);
				$country = new Country((int) $delivery->id_country);
				$customer = new Customer((int)$order->id_customer);
				$messageList = Message::getMessagesByOrderId((int)$order->id);

				$RAPIDEXPRESS_REFERENCE = $datosEnvio['dest_referencia'];
				$RAPIDEXPRESS_ORDER_COMMENTS = $datosEnvio['dest_comentarios'];
				$RAPIDEXPRESS_DEST_CONTACT_INFO = $datosEnvio['dest_nombre'];
				$RAPIDEXPRESS_DEST_PHONE = $datosEnvio['dest_telefono'];
				$RAPIDEXPRESS_DEST_CP = $datosEnvio['dest_cp'];
				$RAPIDEXPRESS_DEST_CITY = $datosEnvio['dest_ciudad'];
				$RAPIDEXPRESS_DEST_ADDRESS = $datosEnvio['dest_direccion'];
				$RAPIDEXPRESS_DEST_COUNTRY = $datosEnvio['dest_pais'];
				$RAPIDEXPRESS_DEST_EMAIL = $customer->email;
				$RAPIDEXPRESS_DEST_COD = ($order->total_shipping_tax_excl);
				$RAPIDEXPRESS_SERV = '<option value="'.$datosEnvio['id_servicio'].'">'.$datosEnvio['nombre_servicio'].'</option>';
				$RAPIDEXPRESS_ALBARAN = $datosEnvio['albaran'];
			}			

			$this->context->smarty->assign(
				array(
					'base_url' => _PS_BASE_URL_ . __PS_BASE_URI__,
					'module_name' => $this->name,
					'RAPIDEXPRESS_ID_ENVIO' => $order->id,
					'ps_version' => _PS_VERSION_,
					'showLabelButton' => !$showLabelButton,
					'errorMessage' => $errorMessage,
					'linkLabel' => $linkLabel,
					'RAPIDEXPRESS_REFERENCE' => $RAPIDEXPRESS_REFERENCE,
					'RAPIDEXPRESS_ORDER_COMMENTS' => $RAPIDEXPRESS_ORDER_COMMENTS,
					'RAPIDEXPRESS_DEST_CONTACT_INFO' => $RAPIDEXPRESS_DEST_CONTACT_INFO,
					'RAPIDEXPRESS_DEST_PHONE' => $RAPIDEXPRESS_DEST_PHONE,
					'RAPIDEXPRESS_DEST_CP' => $RAPIDEXPRESS_DEST_CP,
					'RAPIDEXPRESS_DEST_CITY' => $RAPIDEXPRESS_DEST_CITY,
					'RAPIDEXPRESS_DEST_ADDRESS' => $RAPIDEXPRESS_DEST_ADDRESS,
					'RAPIDEXPRESS_DEST_COUNTRY' => $RAPIDEXPRESS_DEST_COUNTRY,
					'RAPIDEXPRESS_DEST_EMAIL' => $RAPIDEXPRESS_DEST_EMAIL,
					'RAPIDEXPRESS_DEST_COD' => $RAPIDEXPRESS_DEST_COD,
					'RAPIDEXPRESS_SERV' => $RAPIDEXPRESS_SERV,
					'RAPIDEXPRESS_ALBARAN' => $RAPIDEXPRESS_ALBARAN,
				)
			);
		}
        $output .= $this->display(__FILE__, 'orders_confirmation.tpl');
		return $output;
	}

	public function descargarAlbaran($id_envio = 0){
		
		if($id_envio){
			$sql = 'SELECT * '
				. 'FROM ' . _DB_PREFIX_ . 'rapid_envios '
				. 'WHERE id_envio = ' . (int) $id_envio . ' AND codigo_envio IS NOT NULL';
			$trackingCode = (bool) Db::getInstance()->getValue($sql);
			$datosEnvio = Db::getInstance()->getRow($sql);
		}
		if($trackingCode){
			
			$data = array(
				"apiKey" => Configuration::get('RAPIDEXPRESS_TOKEN'),
				"envio" => $datosEnvio['codigo_envio'],
			);

			$data_string = json_encode($data);
			$curl = curl_init();
			curl_setopt_array($curl, array(
				CURLOPT_URL => "https://portal.rapidexpress.es/api/obtenerAlbaran.php",
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_ENCODING => "",
				CURLOPT_MAXREDIRS => 10,
				CURLOPT_TIMEOUT => 30,
				CURLOPT_CUSTOMREQUEST => "POST",
				CURLOPT_POSTFIELDS => array("data"=>$data_string),
				CURLOPT_HTTPHEADER => array("cache-control: no-cache"),
			));
			$response = curl_exec($curl);
			$err = curl_error($curl);
			curl_close($curl);
			if ($err) {
				echo "cURL Error #:" . $err;
			} else {
				$response = json_decode($response, true);
				if($response['formato'] == 'PDF'){
					$albaran = dirname(__FILE__)."/albaranes/".md5($datosEnvio['codigo_envio']).".pdf";
					$fh2 = fopen($albaran, 'w') or die("can't open log file to append");
					fwrite($fh2, base64_decode($response['albaran']));
					fclose($fh2);
				}
			}
		}
		return 0;
	}

	public function generarEnvio($id_envio = 0){
		if ($id_envio) {
			$sql = 'SELECT codigo_barras '
				. 'FROM ' . _DB_PREFIX_ . 'tipsa_envios '
				. 'WHERE id_envio = ' . (int) $id_envio . ' AND codigo_barras IS NOT NULL ';
			$trackingCode = (bool) Db::getInstance()->getValue($sql);
		} else {
			//TODO Come back to the list.
		}

		if (!$trackingCode) {
			$recogida = array(
				'nombre' => Configuration::get('RAPIDEXPRESS_ORI_NOMBRE'),
				'contacto' => Configuration::get('RAPIDEXPRESS_ORI_NOMBRE'),
				'direccion' => Configuration::get('RAPIDEXPRESS_ORI_DIRECCION'),
				'cp' => Configuration::get('RAPIDEXPRESS_ORI_CP'),
				'ciudad' => Configuration::get('RAPIDEXPRESS_ORI_CIUDAD'),
				'pais' => Configuration::get('RAPIDEXPRESS_ORI_PAIS'),
				'telefono' => Configuration::get('RAPIDEXPRESS_ORI_TELEFONO'),
				'email' => Configuration::get('RAPIDEXPRESS_ORI_EMAIL'),
				'horario_desde' => '09:00',
				'horario_hasta' => '19:00',
				'fecha_recogida' => date('Y-m-d'),
				'observaciones' => ''
			);

			$productos = Db::getInstance()->ExecuteS(
				'SELECT product_quantity, product_weight '
				. 'FROM ' . _DB_PREFIX_ . 'order_detail '
				. 'WHERE id_order = ' . (int) $id_envio
			);

			$peso = 0;
			foreach ($productos as $producto) {
				$peso += (float) ($producto['product_quantity'] * $producto['product_weight']);
			}
			if ($peso < 1){
				$peso = 0.5;
			}

			$bultos = Configuration::get('packages');
			if ($bultos < 1) {
				$bultos = 1;
			}

			$destino = array(
				'nombre' => Tools::getValue('rapid_dest_contact'),
				'contacto' => Tools::getValue('rapid_dest_contact'),
				'direccion' => Tools::getValue('rapid_dest_address'),
				'cp' => Tools::getValue('rapid_dest_cp'),
				'ciudad' => Tools::getValue('rapid_dest_city'),
				'pais' => Tools::getValue('rapid_dest_country'),
				'telefono' => Tools::getValue('rapid_dest_phone'),
				'email' => Tools::getValue('rapid_dest_email'),
				'kilos' => $peso,
				'bultos' => $bultos,
				'tipo' => 'PAQ',
				'referencia' => Tools::getValue('rapid_dest_reference'),
				'observaciones' => Tools::getValue('rapid_dest_comment'),
				'valor_asegurado' => '0',
				'valor_reembolso' => '0'
			);

			$data = array(
				"apiKey" => Configuration::get('RAPIDEXPRESS_TOKEN'),
				"producto" => Tools::getValue('rapid_service'),
				"recogida" => $recogida,
				"destino" => $destino
			);

			$data_string = json_encode($data);
			$curl = curl_init();
			curl_setopt_array($curl, array(
				CURLOPT_URL => "https://portal.rapidexpress.es/api/solicitarEnvio.php",
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_ENCODING => "",
				CURLOPT_MAXREDIRS => 10,
				CURLOPT_TIMEOUT => 30,
				CURLOPT_CUSTOMREQUEST => "POST",
				CURLOPT_POSTFIELDS => array("data"=>$data_string),
				CURLOPT_HTTPHEADER => array("cache-control: no-cache"),
			));
			
			$response = curl_exec($curl);
			$err = curl_error($curl);
			curl_close($curl);
			if ($err) {
				echo "cURL Error #:" . $err;
			} else {
				$response = json_decode($response, true);
				if($response['result'] == 200){
					$nombreServ = '';
					$servicios = $this->getServiciosContratados();
					foreach ($servicios as $servicio) {
						if($servicio['id'] == $data['producto']){ $nombreServ = $servicio['nombre']; }
					}
					$datos = array(
						'id_envio'			=> $id_envio,
						'id_servicio'		=> addslashes(trim($data['producto'])),
						'nombre_servicio'	=> addslashes(trim($nombreServ)),
						'codigo_envio'		=> addslashes(trim($response['pedido'])),
						'albaran'			=> addslashes(trim($response['albaran'])),
						'fecha'				=> date('Y-m-d H:i:s'),
						'dest_referencia'	=> addslashes(trim($destino['referencia'])),
						'dest_nombre'		=> addslashes(trim($destino['nombre'])),
						'dest_direccion'	=> addslashes(trim($destino['direccion'])),
						'dest_cp'			=> addslashes(trim($destino['cp'])),
						'dest_ciudad'		=> addslashes(trim($destino['ciudad'])),
						'dest_pais'			=> addslashes(trim($destino['pais'])),
						'dest_telefono'		=> addslashes(trim($destino['telefono'])),
						'dest_comentarios'	=> addslashes(trim($destino['observaciones'])),
						'dest_paquetes'		=> addslashes(trim($destino['bultos'])),
					);

					$sql = "INSERT INTO `"._DB_PREFIX_."rapid_envios` (`".implode('`, `',array_keys($datos))."`) VALUES ('".implode("', '",$datos)."');";
					Db::getInstance()->execute($sql);

				} else {				
					return $response['error'];
				}
			}			
			return '';
		}
	}

	public function getServiciosContratados(){
		$servicios = array();
		$data = array("apiKey" => Configuration::get('RAPIDEXPRESS_TOKEN'));
		$data_string = json_encode($data);
		$curl = curl_init();
		curl_setopt_array($curl, array(
			CURLOPT_URL => "https://portal.rapidexpress.es/api/servicios.php",
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 30,
			CURLOPT_CUSTOMREQUEST => "POST",
			CURLOPT_POSTFIELDS => array("data"=>$data_string),
			CURLOPT_HTTPHEADER => array("cache-control: no-cache"),
		));
		$response = curl_exec($curl);
		$err = curl_error($curl);
		curl_close($curl);
		if ($err) {
			echo "cURL Error #:" . $err;
		} else {
			$response = json_decode($response, true);
			foreach ($response['servicios'] as $value) {
				$servicios[] = $value;
			}
		}
		return $servicios;
	}

}
